@@ -23,15 +23,18 @@
 #ifndef DgmlAuxillaryDictionary_h
 #define DgmlAuxillaryDictionary_h
 
-
 // Lists all known DGML 2.0 auxillary strings
 
-namespace GeoSceneAuxillaryDictionary {
-
+namespace Marble
+{
+namespace dgml
+{
     extern const char* dgmlValue_true;
     extern const char* dgmlValue_on;
     extern const char* dgmlValue_texture;
     extern const char* dgmlValue_vector;
+    extern const char* dgmlValue_geodata;
+}
 }
 
 #endif // DgmlAuxillaryDictionary_h
